Representation
==============

.. currentmodule:: pykeen.nn.representation

.. autoclass:: Representation
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Representation.device

   .. rubric:: Methods Summary

   .. autosummary::

      ~Representation.forward
      ~Representation.iter_extra_repr
      ~Representation.post_parameter_update
      ~Representation.reset_parameters

   .. rubric:: Attributes Documentation

   .. autoattribute:: device

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: iter_extra_repr
   .. automethod:: post_parameter_update
   .. automethod:: reset_parameters
